aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorCary Clark <caryclark@skia.org>2018-11-15 08:25:12 -0500
committerSkia Commit-Bot <skia-commit-bot@chromium.org>2018-11-15 14:08:45 +0000
commitabaffd85abb76c2c03054ba39647688299cfd204 (patch)
treefccac5d1ca0962c74c3a5ddd3d34760f4d5dacf7 /include
parent72098a44ffa8bac2c5174afd7887a83cf844a141 (diff)
downloadskqp-abaffd85abb76c2c03054ba39647688299cfd204.tar.gz
bookmaker does deprecated
Bookmaker does not require documentation for public symbols described as "deprecated", "private", or "experimental". Adding one of these words (case-insensitive) to the symbol description in the include file tells bookmaker that the bmh file should not include documentation, and the generated markdown should omit it in its indices and descriptions. Symbols marked as "to be deprecated" or "may be deprecated" are still regarded as public and documented. Private notes in the includes that start with TODO: are omitted as well. This CL updated generated includes to describe its symbols accordingly. The includes will be fully regenerated in a future CL. The corresponding documentation has been deleted from the bmh files, and the web markup has been regenerated. TBR=reed@google.com Docs-Preview: https://skia.org/?cl=169830 Bug: skia: Change-Id: Ie6ec3ccdadb7be9ac15db4811823a30948c4af25 Reviewed-on: https://skia-review.googlesource.com/c/169830 Commit-Queue: Cary Clark <caryclark@skia.org> Auto-Submit: Cary Clark <caryclark@skia.org> Reviewed-by: Cary Clark <caryclark@skia.org>
Diffstat (limited to 'include')
-rw-r--r--include/core/SkBitmap.h2
-rw-r--r--include/core/SkCanvas.h10
-rw-r--r--include/core/SkImage.h7
-rw-r--r--include/core/SkPaint.h7
-rw-r--r--include/core/SkPath.h4
-rw-r--r--include/core/SkPixmap.h2
-rw-r--r--include/core/SkRect.h3
-rw-r--r--include/core/SkRegion.h2
-rw-r--r--include/core/SkSurface.h5
9 files changed, 27 insertions, 15 deletions
diff --git a/include/core/SkBitmap.h b/include/core/SkBitmap.h
index 1fd19f02ac..0b7339db27 100644
--- a/include/core/SkBitmap.h
+++ b/include/core/SkBitmap.h
@@ -654,7 +654,7 @@ public:
*/
bool installPixels(const SkPixmap& pixmap);
- /** To be deprecated soon.
+ /** Deprecated.
*/
bool installMaskPixels(const SkMask& mask);
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h
index 6b42b42fea..7161f99e11 100644
--- a/include/core/SkCanvas.h
+++ b/include/core/SkCanvas.h
@@ -162,7 +162,7 @@ public:
*/
SkCanvas(int width, int height, const SkSurfaceProps* props = nullptr);
- /** To be deprecated soon.
+ /** Deprecated.
*/
explicit SkCanvas(sk_sp<SkBaseDevice> device);
@@ -181,11 +181,13 @@ public:
explicit SkCanvas(const SkBitmap& bitmap);
#ifdef SK_BUILD_FOR_ANDROID_FRAMEWORK
+ /** Private.
+ */
enum class ColorBehavior {
kLegacy, //!< placeholder
};
- /** For use by Android framework only.
+ /** Private. For use by Android framework only.
@param bitmap specifies a bitmap for the canvas to draw into
@param behavior specializes this constructor; value is unused
@@ -610,7 +612,7 @@ public:
#ifdef SK_SUPPORT_LEGACY_CLIPTOLAYERFLAG
kDontClipToLayer_Legacy_SaveLayerFlag =
- kDontClipToLayer_PrivateSaveLayerFlag, //!< to be deprecated soon
+ kDontClipToLayer_PrivateSaveLayerFlag, //!< deprecated
#endif
};
@@ -1809,7 +1811,7 @@ public:
const SkPaint* paint = nullptr);
/**
- * Controls anti-aliasing of each edge of images in an image-set.
+ * Experimental. Controls anti-aliasing of each edge of images in an image-set.
*/
enum QuadAAFlags : unsigned {
kLeft_QuadAAFlag = 0b0001,
diff --git a/include/core/SkImage.h b/include/core/SkImage.h
index b76130cab4..79067af119 100644
--- a/include/core/SkImage.h
+++ b/include/core/SkImage.h
@@ -964,17 +964,20 @@ public:
GrBackendTexture* backendTexture,
BackendTextureReleaseProc* backendTextureReleaseProc);
+ /** Deprecated.
+ */
enum LegacyBitmapMode {
kRO_LegacyBitmapMode, //!< returned bitmap is read-only and immutable
};
- /** Creates raster SkBitmap with same pixels as SkImage. If legacyBitmapMode is
+ /** Deprecated.
+ Creates raster SkBitmap with same pixels as SkImage. If legacyBitmapMode is
kRO_LegacyBitmapMode, returned bitmap is read-only and immutable.
Returns true if SkBitmap is stored in bitmap. Returns false and resets bitmap if
SkBitmap write did not succeed.
@param bitmap storage for legacy SkBitmap
- @param legacyBitmapMode to be deprecated
+ @param legacyBitmapMode bitmap is read-only and immutable
@return true if SkBitmap was created
*/
bool asLegacyBitmap(SkBitmap* bitmap,
diff --git a/include/core/SkPath.h b/include/core/SkPath.h
index 9b1e324a48..9192419110 100644
--- a/include/core/SkPath.h
+++ b/include/core/SkPath.h
@@ -1678,7 +1678,11 @@ public:
*/
bool isValid() const { return this->isValidImpl() && fPathRef->isValid(); }
#else
+ /** Deprecated.
+ */
bool isValid() const { return this->isValidImpl(); }
+ /** Deprecated.
+ */
bool pathRefIsValid() const { return fPathRef->isValid(); }
#endif
diff --git a/include/core/SkPixmap.h b/include/core/SkPixmap.h
index 94c7e988e5..5c15876d77 100644
--- a/include/core/SkPixmap.h
+++ b/include/core/SkPixmap.h
@@ -106,7 +106,7 @@ public:
*/
void setColorSpace(sk_sp<SkColorSpace> colorSpace);
- /** To be deprecated soon.
+ /** Deprecated.
*/
bool SK_WARN_UNUSED_RESULT reset(const SkMask& mask);
diff --git a/include/core/SkRect.h b/include/core/SkRect.h
index cf309cda1b..1748955e89 100644
--- a/include/core/SkRect.h
+++ b/include/core/SkRect.h
@@ -934,7 +934,8 @@ struct SK_API SkRect {
/** Returns four points in quad that enclose SkRect ordered as: top-left, top-right,
bottom-right, bottom-left.
- Consider adding param to control whether quad is clockwise or counterclockwise.
+
+ TODO: Consider adding parameter to control whether quad is clockwise or counterclockwise.
@param quad storage for corners of SkRect
*/
diff --git a/include/core/SkRegion.h b/include/core/SkRegion.h
index b353484ec4..c5bd825cec 100644
--- a/include/core/SkRegion.h
+++ b/include/core/SkRegion.h
@@ -453,7 +453,7 @@ public:
bool op(const SkRegion& rgna, const SkRegion& rgnb, Op op);
#ifdef SK_BUILD_FOR_ANDROID
- /** Android framework only.
+ /** Private. Android framework only.
@return string representation of SkRegion
*/
diff --git a/include/core/SkSurface.h b/include/core/SkSurface.h
index 1936f4417f..0c7d36a264 100644
--- a/include/core/SkSurface.h
+++ b/include/core/SkSurface.h
@@ -412,8 +412,7 @@ public:
/** Notifies that SkSurface contents will be changed by code outside of Skia.
Subsequent calls to generationID() return a different value.
- mode is normally passed as kRetain_ContentChangeMode.
- Can we deprecate this?
+ TODO: Can kRetain_ContentChangeMode be deprecated?
@param mode one of: kDiscard_ContentChangeMode, kRetain_ContentChangeMode
*/
@@ -647,7 +646,7 @@ public:
*/
const SkSurfaceProps& props() const { return fProps; }
- /** To be deprecated soon.
+ /** Deprecated.
*/
void prepareForExternalIO();
diff --git a/include/core/SkPaint.h b/include/core/SkPaint.h
index 3ae2a66bfd..b43ecc657d 100644
--- a/include/core/SkPaint.h
+++ b/include/core/SkPaint.h
@@ -186,6 +186,7 @@ public:
void reset();
/** \enum SkPaint::Hinting
+ Deprecated.
Hinting adjusts the glyph outlines so that the shape provides a uniform
look at a given point size on font engines that support it. Hinting may have a
muted effect or no effect at all depending on the platform.
@@ -209,13 +210,13 @@ public:
void setHinting(SkFontHinting hintingLevel);
#ifdef SK_SUPPORT_LEGACY_NESTED_HINTINGENUM
/** Returns level of glyph outline adjustment.
@return one of: kNo_Hinting, kSlight_Hinting, kNormal_Hinting, kFull_Hinting
*/
Hinting getHinting() const { return (Hinting)fBitfields.fHinting; }
/** Sets level of glyph outline adjustment.
Does not check for valid values of h.
@param h one of: kNo_Hinting, kSlight_Hinting, kNormal_Hinting, kFull_Hinting
@@ -253,6 +254,8 @@ public:
};
#ifdef SK_BUILD_FOR_ANDROID_FRAMEWORK
+ /** Private.
+ */
enum ReserveFlags {
kUnderlineText_ReserveFlag = 0x08, //!< to be deprecated soon
kStrikeThruText_ReserveFlag = 0x10, //!< to be deprecated soon
@@ -209,13 +210,13 @@ public:
void setHinting(SkFontHinting hintingLevel);
#ifdef SK_SUPPORT_LEGACY_NESTED_HINTINGENUM
- /** Returns level of glyph outline adjustment.
+ /** Deprecated. Returns level of glyph outline adjustment.
*/
@@ -209,13 +210,13 @@ public:
*/
Hinting getHinting() const { return (Hinting)fBitfields.fHinting; }
- /** Sets level of glyph outline adjustment.
+ /** Deprecated. Sets level of glyph outline adjustment.
Does not check for valid values of h.